@@ -210,7 +210,7 @@ class PortfolioHandler(DBHandler):
             return self.placeholders.get("portfolio", {})
         _portfolio = self.latest_portfolio()
         filtered_portfolio = omit(
-            ['user_id', 'episode', 'type', 'timestamp', 'exchange', 'live', 'session', 'time', 'event_id'], 
+            ['user_id', 'episode', 'type', 'timestamp', 'exchange', 'live', 'session', 'time', 'event_id', 'detail'], 
             _portfolio
         )
         return filtered_portfolio
@@ -221,7 +221,7 @@ class PortfolioHandler(DBHandler):
         if self.has_updated:
             return self.placeholders.get("portfolio_history", [])
         portfolio = self.load_portfolio()
-        filtration_list = ['user_id', 'episode', 'type', 'timestamp', 'exchange', 'live', 'event_id']
+        filtration_list = ['user_id', 'episode', 'type', 'timestamp', 'exchange', 'live', 'event_id', 'detail']
         filtered_portfolio = list(map(lambda x: omit(filtration_list, x), portfolio))
         return filtered_portfolio
 
@@ -253,8 +253,7 @@ class PortfolioHandler(DBHandler):
             return net_worth
 
 
-        portfolio_filtered = omit(['user_id', 'episode', 'type', 'time', 'timestamp', 'exchange', 'live', 'event_id'], portfolio)
-
+        portfolio_filtered = omit(['user_id', 'episode', 'type', 'time', 'timestamp', 'exchange', 'live', 'event_id', 'detail'], portfolio)
         for symbol, amount in portfolio_filtered.items():
             if symbol == self._base_instrument:
                 continue
@@ -466,6 +465,7 @@ class PortfolioHandler(DBHandler):
 
     def save_portfolio(self, data):
         """ Save portfolio """
+        alt = {"detail": "portfolio"}
         _data = copy.copy(self._query)
         _data.update(data)
         _data['type'] = self.entity
@@ -474,7 +474,7 @@ class PortfolioHandler(DBHandler):
         for key, value in _data.items():
             if isinstance(value, np.float64):
                 _data[key] = float(value)
-        self.save(_data)
+        self.save(_data, alt=alt)
 
     def save_performance(self, data) -> None:
         """ Save performance information """
@@ -546,8 +546,8 @@ class PortfolioHandler(DBHandler):
         current_balance = float(self.balance)
         portfolio = self.portfolio
         portfolio[self._base_instrument] = current_balance
-
-
+        # print(portfolio)
+        
         latest_performance = {
             'net_worth': self.net_worth,
             'balance': current_balance
@@ -572,7 +572,7 @@ class PortfolioHandler(DBHandler):
         }
 
         self.save_performance(latest_performance)
-        self.save_portfolio(self.portfolio)
+        self.save_portfolio(portfolio)
         self._update_holdings()
 
 
@@ -583,8 +583,8 @@ class PortfolioHandler(DBHandler):
         if not portfolio:
             return 
 
-
-        portfolio_filtered = omit(['user_id', 'episode', 'type', 'time', 'timestamp', 'exchange', 'live', 'event_id'], portfolio)
+        
+        portfolio_filtered = omit(['user_id', 'episode', 'type', 'time', 'timestamp', 'exchange', 'live', 'event_id', 'detail'], portfolio)
 
         """
                 "exchange": "superhotfyre",
@@ -602,7 +602,7 @@ class PortfolioHandler(DBHandler):
 
         """
 
-
+        
         portfolio_items = portfolio_filtered.items()
         for symbol, amount in portfolio_items:
             if symbol == self._base_instrument:
@@ -962,6 +962,8 @@ def main():
     portfolio_hand.add_asset(asset_list[0], subcat)
     portfolio_hand.add_asset(asset_list[1], subcat)
     portfolio_hand.add_asset(asset_list[2], subcat)
+    portfolio_hand.is_inner_allocation = True
+    portfolio_hand.step_price()
     for _ in range(100):
         if random.uniform(0, 1) < 0.1:
             symbol = random.choice([asset_list[0], asset_list[1], asset_list[2]])
